# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/bigquery_datatransfer_v1/proto/datatransfer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.bigquery_datatransfer_v1.proto import (
    transfer_pb2 as google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2,
)
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/bigquery_datatransfer_v1/proto/datatransfer.proto",
    package="google.cloud.bigquery.datatransfer.v1",
    syntax="proto3",
    serialized_options=b"\n)com.google.cloud.bigquery.datatransfer.v1B\021DataTransferProtoP\001ZQgoogle.golang.org/genproto/googleapis/cloud/bigquery/datatransfer/v1;datatransfer\252\002%Google.Cloud.BigQuery.DataTransfer.V1\312\002%Google\\Cloud\\BigQuery\\DataTransfer\\V1\352\002)Google::Cloud::Bigquery::DataTransfer::V1",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n>google/cloud/bigquery_datatransfer_v1/proto/datatransfer.proto\x12%google.cloud.bigquery.datatransfer.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a:google/cloud/bigquery_datatransfer_v1/proto/transfer.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto"\x85\x05\n\x13\x44\x61taSourceParameter\x12\x10\n\x08param_id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12M\n\x04type\x18\x04 \x01(\x0e\x32?.google.cloud.bigquery.datatransfer.v1.DataSourceParameter.Type\x12\x10\n\x08required\x18\x05 \x01(\x08\x12\x10\n\x08repeated\x18\x06 \x01(\x08\x12\x18\n\x10validation_regex\x18\x07 \x01(\t\x12\x16\n\x0e\x61llowed_values\x18\x08 \x03(\t\x12/\n\tmin_value\x18\t \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12/\n\tmax_value\x18\n \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12J\n\x06\x66ields\x18\x0b \x03(\x0b\x32:.google.cloud.bigquery.datatransfer.v1.DataSourceParameter\x12\x1e\n\x16validation_description\x18\x0c \x01(\t\x12\x1b\n\x13validation_help_url\x18\r \x01(\t\x12\x11\n\timmutable\x18\x0e \x01(\x08\x12\x0f\n\x07recurse\x18\x0f \x01(\x08\x12\x12\n\ndeprecated\x18\x14 \x01(\x08"i\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06STRING\x10\x01\x12\x0b\n\x07INTEGER\x10\x02\x12\n\n\x06\x44OUBLE\x10\x03\x12\x0b\n\x07\x42OOLEAN\x10\x04\x12\n\n\x06RECORD\x10\x05\x12\r\n\tPLUS_PAGE\x10\x06"\x9c\t\n\nDataSource\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x03\x12\x16\n\x0e\x64\x61ta_source_id\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\tclient_id\x18\x05 \x01(\t\x12\x0e\n\x06scopes\x18\x06 \x03(\t\x12N\n\rtransfer_type\x18\x07 \x01(\x0e\x32\x33.google.cloud.bigquery.datatransfer.v1.TransferTypeB\x02\x18\x01\x12\'\n\x1bsupports_multiple_transfers\x18\x08 \x01(\x08\x42\x02\x18\x01\x12\x1f\n\x17update_deadline_seconds\x18\t \x01(\x05\x12\x18\n\x10\x64\x65\x66\x61ult_schedule\x18\n \x01(\t\x12 \n\x18supports_custom_schedule\x18\x0b \x01(\x08\x12N\n\nparameters\x18\x0c \x03(\x0b\x32:.google.cloud.bigquery.datatransfer.v1.DataSourceParameter\x12\x10\n\x08help_url\x18\r \x01(\t\x12_\n\x12\x61uthorization_type\x18\x0e \x01(\x0e\x32\x43.google.cloud.bigquery.datatransfer.v1.DataSource.AuthorizationType\x12\\\n\x11\x64\x61ta_refresh_type\x18\x0f \x01(\x0e\x32\x41.google.cloud.bigquery.datatransfer.v1.DataSource.DataRefreshType\x12(\n default_data_refresh_window_days\x18\x10 \x01(\x05\x12\x1c\n\x14manual_runs_disabled\x18\x11 \x01(\x08\x12<\n\x19minimum_schedule_interval\x18\x12 \x01(\x0b\x32\x19.google.protobuf.Duration"\x8a\x01\n\x11\x41uthorizationType\x12"\n\x1e\x41UTHORIZATION_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x41UTHORIZATION_CODE\x10\x01\x12"\n\x1eGOOGLE_PLUS_AUTHORIZATION_CODE\x10\x02\x12\x15\n\x11\x46IRST_PARTY_OAUTH\x10\x03"c\n\x0f\x44\x61taRefreshType\x12!\n\x1d\x44\x41TA_REFRESH_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0eSLIDING_WINDOW\x10\x01\x12\x19\n\x15\x43USTOM_SLIDING_WINDOW\x10\x02:\xa5\x01\xea\x41\xa1\x01\n.bigquerydatatransfer.googleapis.com/DataSource\x12,projects/{project}/dataSources/{data_source}\x12\x41projects/{project}/locations/{location}/dataSources/{data_source}"\\\n\x14GetDataSourceRequest\x12\x44\n\x04name\x18\x01 \x01(\tB6\xe0\x41\x02\xfa\x41\x30\n.bigquerydatatransfer.googleapis.com/DataSource"\x87\x01\n\x16ListDataSourcesRequest\x12\x46\n\x06parent\x18\x01 \x01(\tB6\xe0\x41\x02\xfa\x41\x30\x12.bigquerydatatransfer.googleapis.com/DataSource\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05"\x80\x01\n\x17ListDataSourcesResponse\x12G\n\x0c\x64\x61ta_sources\x18\x01 \x03(\x0b\x32\x31.google.cloud.bigquery.datatransfer.v1.DataSource\x12\x1c\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03"\x8e\x02\n\x1b\x43reateTransferConfigRequest\x12J\n\x06parent\x18\x01 \x01(\tB:\xe0\x41\x02\xfa\x41\x34\x12\x32\x62igquerydatatransfer.googleapis.com/TransferConfig\x12S\n\x0ftransfer_config\x18\x02 \x01(\x0b\x32\x35.google.cloud.bigquery.datatransfer.v1.TransferConfigB\x03\xe0\x41\x02\x12\x1a\n\x12\x61uthorization_code\x18\x03 \x01(\t\x12\x14\n\x0cversion_info\x18\x05 \x01(\t\x12\x1c\n\x14service_account_name\x18\x06 \x01(\t"\xf8\x01\n\x1bUpdateTransferConfigRequest\x12S\n\x0ftransfer_config\x18\x01 \x01(\x0b\x32\x35.google.cloud.bigquery.datatransfer.v1.TransferConfigB\x03\xe0\x41\x02\x12\x1a\n\x12\x61uthorization_code\x18\x03 \x01(\t\x12\x34\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02\x12\x14\n\x0cversion_info\x18\x05 \x01(\t\x12\x1c\n\x14service_account_name\x18\x06 \x01(\t"d\n\x18GetTransferConfigRequest\x12H\n\x04name\x18\x01 \x01(\tB:\xe0\x41\x02\xfa\x41\x34\n2bigquerydatatransfer.googleapis.com/TransferConfig"g\n\x1b\x44\x65leteTransferConfigRequest\x12H\n\x04name\x18\x01 \x01(\tB:\xe0\x41\x02\xfa\x41\x34\n2bigquerydatatransfer.googleapis.com/TransferConfig"V\n\x15GetTransferRunRequest\x12=\n\x04name\x18\x01 \x01(\tB/\xe0\x41\x02\xfa\x41)\n\'bigquerydatatransfer.googleapis.com/Run"Y\n\x18\x44\x65leteTransferRunRequest\x12=\n\x04name\x18\x01 \x01(\tB/\xe0\x41\x02\xfa\x41)\n\'bigquerydatatransfer.googleapis.com/Run"\xa8\x01\n\x1aListTransferConfigsRequest\x12J\n\x06parent\x18\x01 \x01(\tB:\xe0\x41\x02\xfa\x41\x34\x12\x32\x62igquerydatatransfer.googleapis.com/TransferConfig\x12\x17\n\x0f\x64\x61ta_source_ids\x18\x02 \x03(\t\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05"\x91\x01\n\x1bListTransferConfigsResponse\x12T\n\x10transfer_configs\x18\x01 \x03(\x0b\x32\x35.google.cloud.bigquery.datatransfer.v1.TransferConfigB\x03\xe0\x41\x03\x12\x1c\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03"\xde\x02\n\x17ListTransferRunsRequest\x12?\n\x06parent\x18\x01 \x01(\tB/\xe0\x41\x02\xfa\x41)\x12\'bigquerydatatransfer.googleapis.com/Run\x12\x44\n\x06states\x18\x02 \x03(\x0e\x32\x34.google.cloud.bigquery.datatransfer.v1.TransferState\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12^\n\x0brun_attempt\x18\x05 \x01(\x0e\x32I.google.cloud.bigquery.datatransfer.v1.ListTransferRunsRequest.RunAttempt"5\n\nRunAttempt\x12\x1b\n\x17RUN_ATTEMPT_UNSPECIFIED\x10\x00\x12\n\n\x06LATEST\x10\x01"\x88\x01\n\x18ListTransferRunsResponse\x12N\n\rtransfer_runs\x18\x01 \x03(\x0b\x32\x32.google.cloud.bigquery.datatransfer.v1.TransferRunB\x03\xe0\x41\x03\x12\x1c\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03"\xe0\x01\n\x17ListTransferLogsRequest\x12?\n\x06parent\x18\x01 \x01(\tB/\xe0\x41\x02\xfa\x41)\n\'bigquerydatatransfer.googleapis.com/Run\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x11\n\tpage_size\x18\x05 \x01(\x05\x12]\n\rmessage_types\x18\x06 \x03(\x0e\x32\x46.google.cloud.bigquery.datatransfer.v1.TransferMessage.MessageSeverity"\x90\x01\n\x18ListTransferLogsResponse\x12V\n\x11transfer_messages\x18\x01 \x03(\x0b\x32\x36.google.cloud.bigquery.datatransfer.v1.TransferMessageB\x03\xe0\x41\x03\x12\x1c\n\x0fnext_page_token\x18\x02 \x01(\tB\x03\xe0\x41\x03"^\n\x16\x43heckValidCredsRequest\x12\x44\n\x04name\x18\x01 \x01(\tB6\xe0\x41\x02\xfa\x41\x30\n.bigquerydatatransfer.googleapis.com/DataSource"2\n\x17\x43heckValidCredsResponse\x12\x17\n\x0fhas_valid_creds\x18\x01 \x01(\x08"\xd1\x01\n\x1bScheduleTransferRunsRequest\x12J\n\x06parent\x18\x01 \x01(\tB:\xe0\x41\x02\xfa\x41\x34\n2bigquerydatatransfer.googleapis.com/TransferConfig\x12\x33\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x02\x12\x31\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x02"`\n\x1cScheduleTransferRunsResponse\x12@\n\x04runs\x18\x01 \x03(\x0b\x32\x32.google.cloud.bigquery.datatransfer.v1.TransferRun"\x87\x03\n\x1eStartManualTransferRunsRequest\x12G\n\x06parent\x18\x01 \x01(\tB7\xfa\x41\x34\n2bigquerydatatransfer.googleapis.com/TransferConfig\x12o\n\x14requested_time_range\x18\x03 \x01(\x0b\x32O.google.cloud.bigquery.datatransfer.v1.StartManualTransferRunsRequest.TimeRangeH\x00\x12\x38\n\x12requested_run_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x1ai\n\tTimeRange\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\n\x04time"c\n\x1fStartManualTransferRunsResponse\x12@\n\x04runs\x18\x01 \x03(\x0b\x32\x32.google.cloud.bigquery.datatransfer.v1.TransferRun2\xc3\x1f\n\x13\x44\x61taTransferService\x12\xe6\x01\n\rGetDataSource\x12;.google.cloud.bigquery.datatransfer.v1.GetDataSourceRequest\x1a\x31.google.cloud.bigquery.datatransfer.v1.DataSource"e\x82\xd3\xe4\x93\x02X\x12//v1/{name=projects/*/locations/*/dataSources/*}Z%\x12#/v1/{name=projects/*/dataSources/*}\xda\x41\x04name\x12\xf9\x01\n\x0fListDataSources\x12=.google.cloud.bigquery.datatransfer.v1.ListDataSourcesRequest\x1a>.google.cloud.bigquery.datatransfer.v1.ListDataSourcesResponse"g\x82\xd3\xe4\x93\x02X\x12//v1/{parent=projects/*/locations/*}/dataSourcesZ%\x12#/v1/{parent=projects/*}/dataSources\xda\x41\x06parent\x12\xb6\x02\n\x14\x43reateTransferConfig\x12\x42.google.cloud.bigquery.datatransfer.v1.CreateTransferConfigRequest\x1a\x35.google.cloud.bigquery.datatransfer.v1.TransferConfig"\xa2\x01\x82\xd3\xe4\x93\x02\x82\x01"3/v1/{parent=projects/*/locations/*}/transferConfigs:\x0ftransfer_configZ:"\'/v1/{parent=projects/*}/transferConfigs:\x0ftransfer_config\xda\x41\x16parent,transfer_config\x12\xdb\x02\n\x14UpdateTransferConfig\x12\x42.google.cloud.bigquery.datatransfer.v1.UpdateTransferConfigRequest\x1a\x35.google.cloud.bigquery.datatransfer.v1.TransferConfig"\xc7\x01\x82\xd3\xe4\x93\x02\xa2\x01\x32\x43/v1/{transfer_config.name=projects/*/locations/*/transferConfigs/*}:\x0ftransfer_configZJ27/v1/{transfer_config.name=projects/*/transferConfigs/*}:\x0ftransfer_config\xda\x41\x1btransfer_config,update_mask\x12\xe1\x01\n\x14\x44\x65leteTransferConfig\x12\x42.google.cloud.bigquery.datatransfer.v1.DeleteTransferConfigRequest\x1a\x16.google.protobuf.Empty"m\x82\xd3\xe4\x93\x02`*3/v1/{name=projects/*/locations/*/transferConfigs/*}Z)*\'/v1/{name=projects/*/transferConfigs/*}\xda\x41\x04name\x12\xfa\x01\n\x11GetTransferConfig\x12?.google.cloud.bigquery.datatransfer.v1.GetTransferConfigRequest\x1a\x35.google.cloud.bigquery.datatransfer.v1.TransferConfig"m\x82\xd3\xe4\x93\x02`\x12\x33/v1/{name=projects/*/locations/*/transferConfigs/*}Z)\x12\'/v1/{name=projects/*/transferConfigs/*}\xda\x41\x04name\x12\x8d\x02\n\x13ListTransferConfigs\x12\x41.google.cloud.bigquery.datatransfer.v1.ListTransferConfigsRequest\x1a\x42.google.cloud.bigquery.datatransfer.v1.ListTransferConfigsResponse"o\x82\xd3\xe4\x93\x02`\x12\x33/v1/{parent=projects/*/locations/*}/transferConfigsZ)\x12\'/v1/{parent=projects/*}/transferConfigs\xda\x41\x06parent\x12\xcd\x02\n\x14ScheduleTransferRuns\x12\x42.google.cloud.bigquery.datatransfer.v1.ScheduleTransferRunsRequest\x1a\x43.google.cloud.bigquery.datatransfer.v1.ScheduleTransferRunsResponse"\xab\x01\x88\x02\x01\x82\xd3\xe4\x93\x02\x84\x01"B/v1/{parent=projects/*/locations/*/transferConfigs/*}:scheduleRuns:\x01*Z;"6/v1/{parent=projects/*/transferConfigs/*}:scheduleRuns:\x01*\xda\x41\x1aparent,start_time,end_time\x12\xbc\x02\n\x17StartManualTransferRuns\x12\x45.google.cloud.bigquery.datatransfer.v1.StartManualTransferRunsRequest\x1a\x46.google.cloud.bigquery.datatransfer.v1.StartManualTransferRunsResponse"\x91\x01\x82\xd3\xe4\x93\x02\x8a\x01"E/v1/{parent=projects/*/locations/*/transferConfigs/*}:startManualRuns:\x01*Z>"9/v1/{parent=projects/*/transferConfigs/*}:startManualRuns:\x01*\x12\xff\x01\n\x0eGetTransferRun\x12<.google.cloud.bigquery.datatransfer.v1.GetTransferRunRequest\x1a\x32.google.cloud.bigquery.datatransfer.v1.TransferRun"{\x82\xd3\xe4\x93\x02n\x12:/v1/{name=projects/*/locations/*/transferConfigs/*/runs/*}Z0\x12./v1/{name=projects/*/transferConfigs/*/runs/*}\xda\x41\x04name\x12\xe9\x01\n\x11\x44\x65leteTransferRun\x12?.google.cloud.bigquery.datatransfer.v1.DeleteTransferRunRequest\x1a\x16.google.protobuf.Empty"{\x82\xd3\xe4\x93\x02n*:/v1/{name=projects/*/locations/*/transferConfigs/*/runs/*}Z0*./v1/{name=projects/*/transferConfigs/*/runs/*}\xda\x41\x04name\x12\x92\x02\n\x10ListTransferRuns\x12>.google.cloud.bigquery.datatransfer.v1.ListTransferRunsRequest\x1a?.google.cloud.bigquery.datatransfer.v1.ListTransferRunsResponse"}\x82\xd3\xe4\x93\x02n\x12:/v1/{parent=projects/*/locations/*/transferConfigs/*}/runsZ0\x12./v1/{parent=projects/*/transferConfigs/*}/runs\xda\x41\x06parent\x12\xb2\x02\n\x10ListTransferLogs\x12>.google.cloud.bigquery.datatransfer.v1.ListTransferLogsRequest\x1a?.google.cloud.bigquery.datatransfer.v1.ListTransferLogsResponse"\x9c\x01\x82\xd3\xe4\x93\x02\x8c\x01\x12I/v1/{parent=projects/*/locations/*/transferConfigs/*/runs/*}/transferLogsZ?\x12=/v1/{parent=projects/*/transferConfigs/*/runs/*}/transferLogs\xda\x41\x06parent\x12\x9e\x02\n\x0f\x43heckValidCreds\x12=.google.cloud.bigquery.datatransfer.v1.CheckValidCredsRequest\x1a>.google.cloud.bigquery.datatransfer.v1.CheckValidCredsResponse"\x8b\x01\x82\xd3\xe4\x93\x02~"?/v1/{name=projects/*/locations/*/dataSources/*}:checkValidCreds:\x01*Z8"3/v1/{name=projects/*/dataSources/*}:checkValidCreds:\x01*\xda\x41\x04name\x1aW\xca\x41#bigquerydatatransfer.googleapis.com\xd2\x41.https://www.googleapis.com/auth/cloud-platformB\x8f\x02\n)com.google.cloud.bigquery.datatransfer.v1B\x11\x44\x61taTransferProtoP\x01ZQgoogle.golang.org/genproto/googleapis/cloud/bigquery/datatransfer/v1;datatransfer\xaa\x02%Google.Cloud.BigQuery.DataTransfer.V1\xca\x02%Google\\Cloud\\BigQuery\\DataTransfer\\V1\xea\x02)Google::Cloud::Bigquery::DataTransfer::V1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,
    ],
)


_DATASOURCEPARAMETER_TYPE = _descriptor.EnumDescriptor(
    name="Type",
    full_name="google.cloud.bigquery.datatransfer.v1.DataSourceParameter.Type",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="STRING",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="INTEGER",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="DOUBLE",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="BOOLEAN",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="RECORD",
            index=5,
            number=5,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="PLUS_PAGE",
            index=6,
            number=6,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=981,
    serialized_end=1086,
)
_sym_db.RegisterEnumDescriptor(_DATASOURCEPARAMETER_TYPE)

_DATASOURCE_AUTHORIZATIONTYPE = _descriptor.EnumDescriptor(
    name="AuthorizationType",
    full_name="google.cloud.bigquery.datatransfer.v1.DataSource.AuthorizationType",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="AUTHORIZATION_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="AUTHORIZATION_CODE",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="GOOGLE_PLUS_AUTHORIZATION_CODE",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="FIRST_PARTY_OAUTH",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1862,
    serialized_end=2000,
)
_sym_db.RegisterEnumDescriptor(_DATASOURCE_AUTHORIZATIONTYPE)

_DATASOURCE_DATAREFRESHTYPE = _descriptor.EnumDescriptor(
    name="DataRefreshType",
    full_name="google.cloud.bigquery.datatransfer.v1.DataSource.DataRefreshType",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="DATA_REFRESH_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="SLIDING_WINDOW",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="CUSTOM_SLIDING_WINDOW",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=2002,
    serialized_end=2101,
)
_sym_db.RegisterEnumDescriptor(_DATASOURCE_DATAREFRESHTYPE)

_LISTTRANSFERRUNSREQUEST_RUNATTEMPT = _descriptor.EnumDescriptor(
    name="RunAttempt",
    full_name="google.cloud.bigquery.datatransfer.v1.ListTransferRunsRequest.RunAttempt",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="RUN_ATTEMPT_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="LATEST",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=4161,
    serialized_end=4214,
)
_sym_db.RegisterEnumDescriptor(_LISTTRANSFERRUNSREQUEST_RUNATTEMPT)


_DATASOURCEPARAMETER = _descriptor.Descriptor(
    name="DataSourceParameter",
    full_name="google.cloud.bigquery.datatransfer.v1.DataSourceParameter",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="param_id",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceParameter.param_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceParameter.display_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceParameter.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="type",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceParameter.type",
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="required",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceParameter.required",
            index=4,
            number=5,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="repeated",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceParameter.repeated",
            index=5,
            number=6,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="validation_regex",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceParameter.validation_regex",
            index=6,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="allowed_values",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceParameter.allowed_values",
            index=7,
            number=8,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="min_value",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceParameter.min_value",
            index=8,
            number=9,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="max_value",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceParameter.max_value",
            index=9,
            number=10,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="fields",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceParameter.fields",
            index=10,
            number=11,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="validation_description",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceParameter.validation_description",
            index=11,
            number=12,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="validation_help_url",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceParameter.validation_help_url",
            index=12,
            number=13,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="immutable",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceParameter.immutable",
            index=13,
            number=14,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="recurse",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceParameter.recurse",
            index=14,
            number=15,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="deprecated",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSourceParameter.deprecated",
            index=15,
            number=20,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_DATASOURCEPARAMETER_TYPE,],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=441,
    serialized_end=1086,
)


_DATASOURCE = _descriptor.Descriptor(
    name="DataSource",
    full_name="google.cloud.bigquery.datatransfer.v1.DataSource",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSource.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="data_source_id",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSource.data_source_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSource.display_name",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSource.description",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="client_id",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSource.client_id",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="scopes",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSource.scopes",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="transfer_type",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSource.transfer_type",
            index=6,
            number=7,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\030\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="supports_multiple_transfers",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSource.supports_multiple_transfers",
            index=7,
            number=8,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\030\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_deadline_seconds",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSource.update_deadline_seconds",
            index=8,
            number=9,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="default_schedule",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSource.default_schedule",
            index=9,
            number=10,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="supports_custom_schedule",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSource.supports_custom_schedule",
            index=10,
            number=11,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="parameters",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSource.parameters",
            index=11,
            number=12,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="help_url",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSource.help_url",
            index=12,
            number=13,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="authorization_type",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSource.authorization_type",
            index=13,
            number=14,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="data_refresh_type",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSource.data_refresh_type",
            index=14,
            number=15,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="default_data_refresh_window_days",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSource.default_data_refresh_window_days",
            index=15,
            number=16,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="manual_runs_disabled",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSource.manual_runs_disabled",
            index=16,
            number=17,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="minimum_schedule_interval",
            full_name="google.cloud.bigquery.datatransfer.v1.DataSource.minimum_schedule_interval",
            index=17,
            number=18,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_DATASOURCE_AUTHORIZATIONTYPE, _DATASOURCE_DATAREFRESHTYPE,],
    serialized_options=b"\352A\241\001\n.bigquerydatatransfer.googleapis.com/DataSource\022,projects/{project}/dataSources/{data_source}\022Aprojects/{project}/locations/{location}/dataSources/{data_source}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1089,
    serialized_end=2269,
)


_GETDATASOURCEREQUEST = _descriptor.Descriptor(
    name="GetDataSourceRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.GetDataSourceRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.bigquery.datatransfer.v1.GetDataSourceRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A0\n.bigquerydatatransfer.googleapis.com/DataSource",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2271,
    serialized_end=2363,
)


_LISTDATASOURCESREQUEST = _descriptor.Descriptor(
    name="ListDataSourcesRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.ListDataSourcesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.bigquery.datatransfer.v1.ListDataSourcesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A0\022.bigquerydatatransfer.googleapis.com/DataSource",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.bigquery.datatransfer.v1.ListDataSourcesRequest.page_token",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.bigquery.datatransfer.v1.ListDataSourcesRequest.page_size",
            index=2,
            number=4,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2366,
    serialized_end=2501,
)


_LISTDATASOURCESRESPONSE = _descriptor.Descriptor(
    name="ListDataSourcesResponse",
    full_name="google.cloud.bigquery.datatransfer.v1.ListDataSourcesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="data_sources",
            full_name="google.cloud.bigquery.datatransfer.v1.ListDataSourcesResponse.data_sources",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.bigquery.datatransfer.v1.ListDataSourcesResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2504,
    serialized_end=2632,
)


_CREATETRANSFERCONFIGREQUEST = _descriptor.Descriptor(
    name="CreateTransferConfigRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.CreateTransferConfigRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.bigquery.datatransfer.v1.CreateTransferConfigRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A4\0222bigquerydatatransfer.googleapis.com/TransferConfig",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="transfer_config",
            full_name="google.cloud.bigquery.datatransfer.v1.CreateTransferConfigRequest.transfer_config",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="authorization_code",
            full_name="google.cloud.bigquery.datatransfer.v1.CreateTransferConfigRequest.authorization_code",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="version_info",
            full_name="google.cloud.bigquery.datatransfer.v1.CreateTransferConfigRequest.version_info",
            index=3,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="service_account_name",
            full_name="google.cloud.bigquery.datatransfer.v1.CreateTransferConfigRequest.service_account_name",
            index=4,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2635,
    serialized_end=2905,
)


_UPDATETRANSFERCONFIGREQUEST = _descriptor.Descriptor(
    name="UpdateTransferConfigRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.UpdateTransferConfigRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="transfer_config",
            full_name="google.cloud.bigquery.datatransfer.v1.UpdateTransferConfigRequest.transfer_config",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="authorization_code",
            full_name="google.cloud.bigquery.datatransfer.v1.UpdateTransferConfigRequest.authorization_code",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.bigquery.datatransfer.v1.UpdateTransferConfigRequest.update_mask",
            index=2,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="version_info",
            full_name="google.cloud.bigquery.datatransfer.v1.UpdateTransferConfigRequest.version_info",
            index=3,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="service_account_name",
            full_name="google.cloud.bigquery.datatransfer.v1.UpdateTransferConfigRequest.service_account_name",
            index=4,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2908,
    serialized_end=3156,
)


_GETTRANSFERCONFIGREQUEST = _descriptor.Descriptor(
    name="GetTransferConfigRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.GetTransferConfigRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.bigquery.datatransfer.v1.GetTransferConfigRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A4\n2bigquerydatatransfer.googleapis.com/TransferConfig",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3158,
    serialized_end=3258,
)


_DELETETRANSFERCONFIGREQUEST = _descriptor.Descriptor(
    name="DeleteTransferConfigRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.DeleteTransferConfigRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.bigquery.datatransfer.v1.DeleteTransferConfigRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A4\n2bigquerydatatransfer.googleapis.com/TransferConfig",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3260,
    serialized_end=3363,
)


_GETTRANSFERRUNREQUEST = _descriptor.Descriptor(
    name="GetTransferRunRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.GetTransferRunRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.bigquery.datatransfer.v1.GetTransferRunRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A)\n'bigquerydatatransfer.googleapis.com/Run",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3365,
    serialized_end=3451,
)


_DELETETRANSFERRUNREQUEST = _descriptor.Descriptor(
    name="DeleteTransferRunRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.DeleteTransferRunRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.bigquery.datatransfer.v1.DeleteTransferRunRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A)\n'bigquerydatatransfer.googleapis.com/Run",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3453,
    serialized_end=3542,
)


_LISTTRANSFERCONFIGSREQUEST = _descriptor.Descriptor(
    name="ListTransferConfigsRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.ListTransferConfigsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.bigquery.datatransfer.v1.ListTransferConfigsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A4\0222bigquerydatatransfer.googleapis.com/TransferConfig",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="data_source_ids",
            full_name="google.cloud.bigquery.datatransfer.v1.ListTransferConfigsRequest.data_source_ids",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.bigquery.datatransfer.v1.ListTransferConfigsRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.bigquery.datatransfer.v1.ListTransferConfigsRequest.page_size",
            index=3,
            number=4,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3545,
    serialized_end=3713,
)


_LISTTRANSFERCONFIGSRESPONSE = _descriptor.Descriptor(
    name="ListTransferConfigsResponse",
    full_name="google.cloud.bigquery.datatransfer.v1.ListTransferConfigsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="transfer_configs",
            full_name="google.cloud.bigquery.datatransfer.v1.ListTransferConfigsResponse.transfer_configs",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.bigquery.datatransfer.v1.ListTransferConfigsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3716,
    serialized_end=3861,
)


_LISTTRANSFERRUNSREQUEST = _descriptor.Descriptor(
    name="ListTransferRunsRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.ListTransferRunsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.bigquery.datatransfer.v1.ListTransferRunsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A)\022'bigquerydatatransfer.googleapis.com/Run",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="states",
            full_name="google.cloud.bigquery.datatransfer.v1.ListTransferRunsRequest.states",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.bigquery.datatransfer.v1.ListTransferRunsRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.bigquery.datatransfer.v1.ListTransferRunsRequest.page_size",
            index=3,
            number=4,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="run_attempt",
            full_name="google.cloud.bigquery.datatransfer.v1.ListTransferRunsRequest.run_attempt",
            index=4,
            number=5,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_LISTTRANSFERRUNSREQUEST_RUNATTEMPT,],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3864,
    serialized_end=4214,
)


_LISTTRANSFERRUNSRESPONSE = _descriptor.Descriptor(
    name="ListTransferRunsResponse",
    full_name="google.cloud.bigquery.datatransfer.v1.ListTransferRunsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="transfer_runs",
            full_name="google.cloud.bigquery.datatransfer.v1.ListTransferRunsResponse.transfer_runs",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.bigquery.datatransfer.v1.ListTransferRunsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4217,
    serialized_end=4353,
)


_LISTTRANSFERLOGSREQUEST = _descriptor.Descriptor(
    name="ListTransferLogsRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.ListTransferLogsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.bigquery.datatransfer.v1.ListTransferLogsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A)\n'bigquerydatatransfer.googleapis.com/Run",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.bigquery.datatransfer.v1.ListTransferLogsRequest.page_token",
            index=1,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.bigquery.datatransfer.v1.ListTransferLogsRequest.page_size",
            index=2,
            number=5,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="message_types",
            full_name="google.cloud.bigquery.datatransfer.v1.ListTransferLogsRequest.message_types",
            index=3,
            number=6,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4356,
    serialized_end=4580,
)


_LISTTRANSFERLOGSRESPONSE = _descriptor.Descriptor(
    name="ListTransferLogsResponse",
    full_name="google.cloud.bigquery.datatransfer.v1.ListTransferLogsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="transfer_messages",
            full_name="google.cloud.bigquery.datatransfer.v1.ListTransferLogsResponse.transfer_messages",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.bigquery.datatransfer.v1.ListTransferLogsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4583,
    serialized_end=4727,
)


_CHECKVALIDCREDSREQUEST = _descriptor.Descriptor(
    name="CheckValidCredsRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.CheckValidCredsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.bigquery.datatransfer.v1.CheckValidCredsRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A0\n.bigquerydatatransfer.googleapis.com/DataSource",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4729,
    serialized_end=4823,
)


_CHECKVALIDCREDSRESPONSE = _descriptor.Descriptor(
    name="CheckValidCredsResponse",
    full_name="google.cloud.bigquery.datatransfer.v1.CheckValidCredsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="has_valid_creds",
            full_name="google.cloud.bigquery.datatransfer.v1.CheckValidCredsResponse.has_valid_creds",
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4825,
    serialized_end=4875,
)


_SCHEDULETRANSFERRUNSREQUEST = _descriptor.Descriptor(
    name="ScheduleTransferRunsRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.ScheduleTransferRunsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.bigquery.datatransfer.v1.ScheduleTransferRunsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A4\n2bigquerydatatransfer.googleapis.com/TransferConfig",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="start_time",
            full_name="google.cloud.bigquery.datatransfer.v1.ScheduleTransferRunsRequest.start_time",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="end_time",
            full_name="google.cloud.bigquery.datatransfer.v1.ScheduleTransferRunsRequest.end_time",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4878,
    serialized_end=5087,
)


_SCHEDULETRANSFERRUNSRESPONSE = _descriptor.Descriptor(
    name="ScheduleTransferRunsResponse",
    full_name="google.cloud.bigquery.datatransfer.v1.ScheduleTransferRunsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="runs",
            full_name="google.cloud.bigquery.datatransfer.v1.ScheduleTransferRunsResponse.runs",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5089,
    serialized_end=5185,
)


_STARTMANUALTRANSFERRUNSREQUEST_TIMERANGE = _descriptor.Descriptor(
    name="TimeRange",
    full_name="google.cloud.bigquery.datatransfer.v1.StartManualTransferRunsRequest.TimeRange",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="start_time",
            full_name="google.cloud.bigquery.datatransfer.v1.StartManualTransferRunsRequest.TimeRange.start_time",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="end_time",
            full_name="google.cloud.bigquery.datatransfer.v1.StartManualTransferRunsRequest.TimeRange.end_time",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5466,
    serialized_end=5571,
)

_STARTMANUALTRANSFERRUNSREQUEST = _descriptor.Descriptor(
    name="StartManualTransferRunsRequest",
    full_name="google.cloud.bigquery.datatransfer.v1.StartManualTransferRunsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.bigquery.datatransfer.v1.StartManualTransferRunsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\372A4\n2bigquerydatatransfer.googleapis.com/TransferConfig",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="requested_time_range",
            full_name="google.cloud.bigquery.datatransfer.v1.StartManualTransferRunsRequest.requested_time_range",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="requested_run_time",
            full_name="google.cloud.bigquery.datatransfer.v1.StartManualTransferRunsRequest.requested_run_time",
            index=2,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[_STARTMANUALTRANSFERRUNSREQUEST_TIMERANGE,],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="time",
            full_name="google.cloud.bigquery.datatransfer.v1.StartManualTransferRunsRequest.time",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=5188,
    serialized_end=5579,
)


_STARTMANUALTRANSFERRUNSRESPONSE = _descriptor.Descriptor(
    name="StartManualTransferRunsResponse",
    full_name="google.cloud.bigquery.datatransfer.v1.StartManualTransferRunsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="runs",
            full_name="google.cloud.bigquery.datatransfer.v1.StartManualTransferRunsResponse.runs",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5581,
    serialized_end=5680,
)

_DATASOURCEPARAMETER.fields_by_name["type"].enum_type = _DATASOURCEPARAMETER_TYPE
_DATASOURCEPARAMETER.fields_by_name[
    "min_value"
].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_DATASOURCEPARAMETER.fields_by_name[
    "max_value"
].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_DATASOURCEPARAMETER.fields_by_name["fields"].message_type = _DATASOURCEPARAMETER
_DATASOURCEPARAMETER_TYPE.containing_type = _DATASOURCEPARAMETER
_DATASOURCE.fields_by_name[
    "transfer_type"
].enum_type = (
    google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2._TRANSFERTYPE
)
_DATASOURCE.fields_by_name["parameters"].message_type = _DATASOURCEPARAMETER
_DATASOURCE.fields_by_name[
    "authorization_type"
].enum_type = _DATASOURCE_AUTHORIZATIONTYPE
_DATASOURCE.fields_by_name["data_refresh_type"].enum_type = _DATASOURCE_DATAREFRESHTYPE
_DATASOURCE.fields_by_name[
    "minimum_schedule_interval"
].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_DATASOURCE_AUTHORIZATIONTYPE.containing_type = _DATASOURCE
_DATASOURCE_DATAREFRESHTYPE.containing_type = _DATASOURCE
_LISTDATASOURCESRESPONSE.fields_by_name["data_sources"].message_type = _DATASOURCE
_CREATETRANSFERCONFIGREQUEST.fields_by_name[
    "transfer_config"
].message_type = (
    google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2._TRANSFERCONFIG
)
_UPDATETRANSFERCONFIGREQUEST.fields_by_name[
    "transfer_config"
].message_type = (
    google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2._TRANSFERCONFIG
)
_UPDATETRANSFERCONFIGREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTTRANSFERCONFIGSRESPONSE.fields_by_name[
    "transfer_configs"
].message_type = (
    google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2._TRANSFERCONFIG
)
_LISTTRANSFERRUNSREQUEST.fields_by_name[
    "states"
].enum_type = (
    google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2._TRANSFERSTATE
)
_LISTTRANSFERRUNSREQUEST.fields_by_name[
    "run_attempt"
].enum_type = _LISTTRANSFERRUNSREQUEST_RUNATTEMPT
_LISTTRANSFERRUNSREQUEST_RUNATTEMPT.containing_type = _LISTTRANSFERRUNSREQUEST
_LISTTRANSFERRUNSRESPONSE.fields_by_name[
    "transfer_runs"
].message_type = (
    google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2._TRANSFERRUN
)
_LISTTRANSFERLOGSREQUEST.fields_by_name[
    "message_types"
].enum_type = (
    google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2._TRANSFERMESSAGE_MESSAGESEVERITY
)
_LISTTRANSFERLOGSRESPONSE.fields_by_name[
    "transfer_messages"
].message_type = (
    google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2._TRANSFERMESSAGE
)
_SCHEDULETRANSFERRUNSREQUEST.fields_by_name[
    "start_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCHEDULETRANSFERRUNSREQUEST.fields_by_name[
    "end_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCHEDULETRANSFERRUNSRESPONSE.fields_by_name[
    "runs"
].message_type = (
    google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2._TRANSFERRUN
)
_STARTMANUALTRANSFERRUNSREQUEST_TIMERANGE.fields_by_name[
    "start_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STARTMANUALTRANSFERRUNSREQUEST_TIMERANGE.fields_by_name[
    "end_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STARTMANUALTRANSFERRUNSREQUEST_TIMERANGE.containing_type = (
    _STARTMANUALTRANSFERRUNSREQUEST
)
_STARTMANUALTRANSFERRUNSREQUEST.fields_by_name[
    "requested_time_range"
].message_type = _STARTMANUALTRANSFERRUNSREQUEST_TIMERANGE
_STARTMANUALTRANSFERRUNSREQUEST.fields_by_name[
    "requested_run_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STARTMANUALTRANSFERRUNSREQUEST.oneofs_by_name["time"].fields.append(
    _STARTMANUALTRANSFERRUNSREQUEST.fields_by_name["requested_time_range"]
)
_STARTMANUALTRANSFERRUNSREQUEST.fields_by_name[
    "requested_time_range"
].containing_oneof = _STARTMANUALTRANSFERRUNSREQUEST.oneofs_by_name["time"]
_STARTMANUALTRANSFERRUNSREQUEST.oneofs_by_name["time"].fields.append(
    _STARTMANUALTRANSFERRUNSREQUEST.fields_by_name["requested_run_time"]
)
_STARTMANUALTRANSFERRUNSREQUEST.fields_by_name[
    "requested_run_time"
].containing_oneof = _STARTMANUALTRANSFERRUNSREQUEST.oneofs_by_name["time"]
_STARTMANUALTRANSFERRUNSRESPONSE.fields_by_name[
    "runs"
].message_type = (
    google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2._TRANSFERRUN
)
DESCRIPTOR.message_types_by_name["DataSourceParameter"] = _DATASOURCEPARAMETER
DESCRIPTOR.message_types_by_name["DataSource"] = _DATASOURCE
DESCRIPTOR.message_types_by_name["GetDataSourceRequest"] = _GETDATASOURCEREQUEST
DESCRIPTOR.message_types_by_name["ListDataSourcesRequest"] = _LISTDATASOURCESREQUEST
DESCRIPTOR.message_types_by_name["ListDataSourcesResponse"] = _LISTDATASOURCESRESPONSE
DESCRIPTOR.message_types_by_name[
    "CreateTransferConfigRequest"
] = _CREATETRANSFERCONFIGREQUEST
DESCRIPTOR.message_types_by_name[
    "UpdateTransferConfigRequest"
] = _UPDATETRANSFERCONFIGREQUEST
DESCRIPTOR.message_types_by_name["GetTransferConfigRequest"] = _GETTRANSFERCONFIGREQUEST
DESCRIPTOR.message_types_by_name[
    "DeleteTransferConfigRequest"
] = _DELETETRANSFERCONFIGREQUEST
DESCRIPTOR.message_types_by_name["GetTransferRunRequest"] = _GETTRANSFERRUNREQUEST
DESCRIPTOR.message_types_by_name["DeleteTransferRunRequest"] = _DELETETRANSFERRUNREQUEST
DESCRIPTOR.message_types_by_name[
    "ListTransferConfigsRequest"
] = _LISTTRANSFERCONFIGSREQUEST
DESCRIPTOR.message_types_by_name[
    "ListTransferConfigsResponse"
] = _LISTTRANSFERCONFIGSRESPONSE
DESCRIPTOR.message_types_by_name["ListTransferRunsRequest"] = _LISTTRANSFERRUNSREQUEST
DESCRIPTOR.message_types_by_name["ListTransferRunsResponse"] = _LISTTRANSFERRUNSRESPONSE
DESCRIPTOR.message_types_by_name["ListTransferLogsRequest"] = _LISTTRANSFERLOGSREQUEST
DESCRIPTOR.message_types_by_name["ListTransferLogsResponse"] = _LISTTRANSFERLOGSRESPONSE
DESCRIPTOR.message_types_by_name["CheckValidCredsRequest"] = _CHECKVALIDCREDSREQUEST
DESCRIPTOR.message_types_by_name["CheckValidCredsResponse"] = _CHECKVALIDCREDSRESPONSE
DESCRIPTOR.message_types_by_name[
    "ScheduleTransferRunsRequest"
] = _SCHEDULETRANSFERRUNSREQUEST
DESCRIPTOR.message_types_by_name[
    "ScheduleTransferRunsResponse"
] = _SCHEDULETRANSFERRUNSRESPONSE
DESCRIPTOR.message_types_by_name[
    "StartManualTransferRunsRequest"
] = _STARTMANUALTRANSFERRUNSREQUEST
DESCRIPTOR.message_types_by_name[
    "StartManualTransferRunsResponse"
] = _STARTMANUALTRANSFERRUNSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataSourceParameter = _reflection.GeneratedProtocolMessageType(
    "DataSourceParameter",
    (_message.Message,),
    {
        "DESCRIPTOR": _DATASOURCEPARAMETER,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """Represents a data source parameter with validation rules, so that
  parameters can be rendered in the UI. These parameters are given to us
  by supported data sources, and include all needed information for
  rendering and validation. Thus, whoever uses this api can decide to
  generate either generic ui, or custom data source specific forms.
  
  Attributes:
      param_id:
          Parameter identifier.
      display_name:
          Parameter display name in the user interface.
      description:
          Parameter description.
      type:
          Parameter type.
      required:
          Is parameter required.
      repeated:
          Deprecated. This field has no effect.
      validation_regex:
          Regular expression which can be used for parameter validation.
      allowed_values:
          All possible values for the parameter.
      min_value:
          For integer and double values specifies minimum allowed value.
      max_value:
          For integer and double values specifies maxminum allowed
          value.
      fields:
          Deprecated. This field has no effect.
      validation_description:
          Description of the requirements for this field, in case the
          user input does not fulfill the regex pattern or min/max
          values.
      validation_help_url:
          URL to a help document to further explain the naming
          requirements.
      immutable:
          Cannot be changed after initial creation.
      recurse:
          Deprecated. This field has no effect.
      deprecated:
          If true, it should not be used in new transfers, and it should
          not be visible to users.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.DataSourceParameter)
    },
)
_sym_db.RegisterMessage(DataSourceParameter)

DataSource = _reflection.GeneratedProtocolMessageType(
    "DataSource",
    (_message.Message,),
    {
        "DESCRIPTOR": _DATASOURCE,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """Represents data source metadata. Metadata is sufficient to render UI
  and request proper OAuth tokens.
  
  Attributes:
      name:
          Output only. Data source resource name.
      data_source_id:
          Data source id.
      display_name:
          User friendly data source name.
      description:
          User friendly data source description string.
      client_id:
          Data source client id which should be used to receive refresh
          token.
      scopes:
          Api auth scopes for which refresh token needs to be obtained.
          These are scopes needed by a data source to prepare data and
          ingest them into BigQuery, e.g.,
          https://www.googleapis.com/auth/bigquery
      transfer_type:
          Deprecated. This field has no effect.
      supports_multiple_transfers:
          Deprecated. This field has no effect.
      update_deadline_seconds:
          The number of seconds to wait for an update from the data
          source before the Data Transfer Service marks the transfer as
          FAILED.
      default_schedule:
          Default data transfer schedule. Examples of valid schedules
          include: ``1st,3rd monday of month 15:30``, ``every wed,fri of
          jan,jun 13:15``, and ``first sunday of quarter 00:00``.
      supports_custom_schedule:
          Specifies whether the data source supports a user defined
          schedule, or operates on the default schedule. When set to
          ``true``, user can override default schedule.
      parameters:
          Data source parameters.
      help_url:
          Url for the help document for this data source.
      authorization_type:
          Indicates the type of authorization.
      data_refresh_type:
          Specifies whether the data source supports automatic data
          refresh for the past few days, and how it’s supported. For
          some data sources, data might not be complete until a few days
          later, so it’s useful to refresh data automatically.
      default_data_refresh_window_days:
          Default data refresh window on days. Only meaningful when
          ``data_refresh_type`` = ``SLIDING_WINDOW``.
      manual_runs_disabled:
          Disables backfilling and manual run scheduling for the data
          source.
      minimum_schedule_interval:
          The minimum interval for scheduler to schedule runs.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.DataSource)
    },
)
_sym_db.RegisterMessage(DataSource)

GetDataSourceRequest = _reflection.GeneratedProtocolMessageType(
    "GetDataSourceRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETDATASOURCEREQUEST,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """A request to get data source info.
  
  Attributes:
      name:
          Required. The field will contain name of the resource
          requested, for example:
          ``projects/{project_id}/dataSources/{data_source_id}`` or ``pr
          ojects/{project_id}/locations/{location_id}/dataSources/{data_
          source_id}``
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.GetDataSourceRequest)
    },
)
_sym_db.RegisterMessage(GetDataSourceRequest)

ListDataSourcesRequest = _reflection.GeneratedProtocolMessageType(
    "ListDataSourcesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTDATASOURCESREQUEST,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """Request to list supported data sources and their data transfer
  settings.
  
  Attributes:
      parent:
          Required. The BigQuery project id for which data sources
          should be returned. Must be in the form:
          ``projects/{project_id}`` or
          \`projects/{project_id}/locations/{location_id}
      page_token:
          Pagination token, which can be used to request a specific page
          of ``ListDataSourcesRequest`` list results. For multiple-page
          results, ``ListDataSourcesResponse`` outputs a ``next_page``
          token, which can be used as the ``page_token`` value to
          request the next page of list results.
      page_size:
          Page size. The default page size is the maximum value of 1000
          results.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.ListDataSourcesRequest)
    },
)
_sym_db.RegisterMessage(ListDataSourcesRequest)

ListDataSourcesResponse = _reflection.GeneratedProtocolMessageType(
    "ListDataSourcesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTDATASOURCESRESPONSE,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """Returns list of supported data sources and their metadata.
  
  Attributes:
      data_sources:
          List of supported data sources and their transfer settings.
      next_page_token:
          Output only. The next-pagination token. For multiple-page list
          results, this token can be used as the
          ``ListDataSourcesRequest.page_token`` to request the next page
          of list results.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.ListDataSourcesResponse)
    },
)
_sym_db.RegisterMessage(ListDataSourcesResponse)

CreateTransferConfigRequest = _reflection.GeneratedProtocolMessageType(
    "CreateTransferConfigRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATETRANSFERCONFIGREQUEST,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """A request to create a data transfer configuration. If new credentials
  are needed for this transfer configuration, an authorization code must
  be provided. If an authorization code is provided, the transfer
  configuration will be associated with the user id corresponding to the
  authorization code. Otherwise, the transfer configuration will be
  associated with the calling user.
  
  Attributes:
      parent:
          Required. The BigQuery project id where the transfer
          configuration should be created. Must be in the format
          projects/{project_id}/locations/{location_id} or
          projects/{project_id}. If specified location and location of
          the destination bigquery dataset do not match - the request
          will fail.
      transfer_config:
          Required. Data transfer configuration to create.
      authorization_code:
          Optional OAuth2 authorization code to use with this transfer
          configuration. This is required if new credentials are needed,
          as indicated by ``CheckValidCreds``. In order to obtain
          authorization_code, please make a request to https://www.gstat
          ic.com/bigquerydatatransfer/oauthz/auth?client_id=&scope=&redi
          rect_uri=  -  client_id should be OAuth client_id of BigQuery
          DTS API for the given    data source returned by
          ListDataSources method. -  data_source_scopes are the scopes
          returned by ListDataSources method. -  redirect_uri is an
          optional parameter. If not specified, then    authorization
          code is posted to the opener of authorization flow    window.
          Otherwise it will be sent to the redirect uri. A special
          value of urn:ietf:wg:oauth:2.0:oob means that authorization
          code    should be returned in the title bar of the browser,
          with the page    text prompting the user to copy the code and
          paste it in the    application.
      version_info:
          Optional version info. If users want to find a very recent
          access token, that is, immediately after approving access,
          users have to set the version_info claim in the token request.
          To obtain the version_info, users must use the “none+gsession”
          response type. which be return a version_info back in the
          authorization response which be be put in a JWT claim in the
          token request.
      service_account_name:
          Optional service account name. If this field is set, transfer
          config will be created with this service account credentials.
          It requires that requesting user calling this API has
          permissions to act as this service account.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.CreateTransferConfigRequest)
    },
)
_sym_db.RegisterMessage(CreateTransferConfigRequest)

UpdateTransferConfigRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateTransferConfigRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATETRANSFERCONFIGREQUEST,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """A request to update a transfer configuration. To update the user id of
  the transfer configuration, an authorization code needs to be
  provided.
  
  Attributes:
      transfer_config:
          Required. Data transfer configuration to create.
      authorization_code:
          Optional OAuth2 authorization code to use with this transfer
          configuration. If it is provided, the transfer configuration
          will be associated with the authorizing user. In order to
          obtain authorization_code, please make a request to https://ww
          w.gstatic.com/bigquerydatatransfer/oauthz/auth?client_id=&scop
          e=&redirect_uri=  -  client_id should be OAuth client_id of
          BigQuery DTS API for the given    data source returned by
          ListDataSources method. -  data_source_scopes are the scopes
          returned by ListDataSources method. -  redirect_uri is an
          optional parameter. If not specified, then    authorization
          code is posted to the opener of authorization flow    window.
          Otherwise it will be sent to the redirect uri. A special
          value of urn:ietf:wg:oauth:2.0:oob means that authorization
          code    should be returned in the title bar of the browser,
          with the page    text prompting the user to copy the code and
          paste it in the    application.
      update_mask:
          Required. Required list of fields to be updated in this
          request.
      version_info:
          Optional version info. If users want to find a very recent
          access token, that is, immediately after approving access,
          users have to set the version_info claim in the token request.
          To obtain the version_info, users must use the “none+gsession”
          response type. which be return a version_info back in the
          authorization response which be be put in a JWT claim in the
          token request.
      service_account_name:
          Optional service account name. If this field is set and
          “service_account_name” is set in update_mask, transfer config
          will be updated to use this service account credentials. It
          requires that requesting user calling this API has permissions
          to act as this service account.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.UpdateTransferConfigRequest)
    },
)
_sym_db.RegisterMessage(UpdateTransferConfigRequest)

GetTransferConfigRequest = _reflection.GeneratedProtocolMessageType(
    "GetTransferConfigRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETTRANSFERCONFIGREQUEST,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """A request to get data transfer information.
  
  Attributes:
      name:
          Required. The field will contain name of the resource
          requested, for example:
          ``projects/{project_id}/transferConfigs/{config_id}`` or ``pro
          jects/{project_id}/locations/{location_id}/transferConfigs/{co
          nfig_id}``
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.GetTransferConfigRequest)
    },
)
_sym_db.RegisterMessage(GetTransferConfigRequest)

DeleteTransferConfigRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteTransferConfigRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETETRANSFERCONFIGREQUEST,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """A request to delete data transfer information. All associated transfer
  runs and log messages will be deleted as well.
  
  Attributes:
      name:
          Required. The field will contain name of the resource
          requested, for example:
          ``projects/{project_id}/transferConfigs/{config_id}`` or ``pro
          jects/{project_id}/locations/{location_id}/transferConfigs/{co
          nfig_id}``
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.DeleteTransferConfigRequest)
    },
)
_sym_db.RegisterMessage(DeleteTransferConfigRequest)

GetTransferRunRequest = _reflection.GeneratedProtocolMessageType(
    "GetTransferRunRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETTRANSFERRUNREQUEST,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """A request to get data transfer run information.
  
  Attributes:
      name:
          Required. The field will contain name of the resource
          requested, for example: ``projects/{project_id}/transferConfig
          s/{config_id}/runs/{run_id}`` or ``projects/{project_id}/locat
          ions/{location_id}/transferConfigs/{config_id}/runs/{run_id}``
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.GetTransferRunRequest)
    },
)
_sym_db.RegisterMessage(GetTransferRunRequest)

DeleteTransferRunRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteTransferRunRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETETRANSFERRUNREQUEST,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """A request to delete data transfer run information.
  
  Attributes:
      name:
          Required. The field will contain name of the resource
          requested, for example: ``projects/{project_id}/transferConfig
          s/{config_id}/runs/{run_id}`` or ``projects/{project_id}/locat
          ions/{location_id}/transferConfigs/{config_id}/runs/{run_id}``
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.DeleteTransferRunRequest)
    },
)
_sym_db.RegisterMessage(DeleteTransferRunRequest)

ListTransferConfigsRequest = _reflection.GeneratedProtocolMessageType(
    "ListTransferConfigsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTTRANSFERCONFIGSREQUEST,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """A request to list data transfers configured for a BigQuery project.
  
  Attributes:
      parent:
          Required. The BigQuery project id for which data sources
          should be returned: ``projects/{project_id}`` or
          ``projects/{project_id}/locations/{location_id}``
      data_source_ids:
          When specified, only configurations of requested data sources
          are returned.
      page_token:
          Pagination token, which can be used to request a specific page
          of ``ListTransfersRequest`` list results. For multiple-page
          results, ``ListTransfersResponse`` outputs a ``next_page``
          token, which can be used as the ``page_token`` value to
          request the next page of list results.
      page_size:
          Page size. The default page size is the maximum value of 1000
          results.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.ListTransferConfigsRequest)
    },
)
_sym_db.RegisterMessage(ListTransferConfigsRequest)

ListTransferConfigsResponse = _reflection.GeneratedProtocolMessageType(
    "ListTransferConfigsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTTRANSFERCONFIGSRESPONSE,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """The returned list of pipelines in the project.
  
  Attributes:
      transfer_configs:
          Output only. The stored pipeline transfer configurations.
      next_page_token:
          Output only. The next-pagination token. For multiple-page list
          results, this token can be used as the
          ``ListTransferConfigsRequest.page_token`` to request the next
          page of list results.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.ListTransferConfigsResponse)
    },
)
_sym_db.RegisterMessage(ListTransferConfigsResponse)

ListTransferRunsRequest = _reflection.GeneratedProtocolMessageType(
    "ListTransferRunsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTTRANSFERRUNSREQUEST,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """A request to list data transfer runs. UI can use this method to
  show/filter specific data transfer runs. The data source can use this
  method to request all scheduled transfer runs.
  
  Attributes:
      parent:
          Required. Name of transfer configuration for which transfer
          runs should be retrieved. Format of transfer configuration
          resource name is:
          ``projects/{project_id}/transferConfigs/{config_id}`` or ``pro
          jects/{project_id}/locations/{location_id}/transferConfigs/{co
          nfig_id}``.
      states:
          When specified, only transfer runs with requested states are
          returned.
      page_token:
          Pagination token, which can be used to request a specific page
          of ``ListTransferRunsRequest`` list results. For multiple-page
          results, ``ListTransferRunsResponse`` outputs a ``next_page``
          token, which can be used as the ``page_token`` value to
          request the next page of list results.
      page_size:
          Page size. The default page size is the maximum value of 1000
          results.
      run_attempt:
          Indicates how run attempts are to be pulled.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.ListTransferRunsRequest)
    },
)
_sym_db.RegisterMessage(ListTransferRunsRequest)

ListTransferRunsResponse = _reflection.GeneratedProtocolMessageType(
    "ListTransferRunsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTTRANSFERRUNSRESPONSE,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """The returned list of pipelines in the project.
  
  Attributes:
      transfer_runs:
          Output only. The stored pipeline transfer runs.
      next_page_token:
          Output only. The next-pagination token. For multiple-page list
          results, this token can be used as the
          ``ListTransferRunsRequest.page_token`` to request the next
          page of list results.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.ListTransferRunsResponse)
    },
)
_sym_db.RegisterMessage(ListTransferRunsResponse)

ListTransferLogsRequest = _reflection.GeneratedProtocolMessageType(
    "ListTransferLogsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTTRANSFERLOGSREQUEST,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """A request to get user facing log messages associated with data
  transfer run.
  
  Attributes:
      parent:
          Required. Transfer run name in the form: ``projects/{project_i
          d}/transferConfigs/{config_id}/runs/{run_id}`` or ``projects/{
          project_id}/locations/{location_id}/transferConfigs/{config_id
          }/runs/{run_id}``
      page_token:
          Pagination token, which can be used to request a specific page
          of ``ListTransferLogsRequest`` list results. For multiple-page
          results, ``ListTransferLogsResponse`` outputs a ``next_page``
          token, which can be used as the ``page_token`` value to
          request the next page of list results.
      page_size:
          Page size. The default page size is the maximum value of 1000
          results.
      message_types:
          Message types to return. If not populated - INFO, WARNING and
          ERROR messages are returned.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.ListTransferLogsRequest)
    },
)
_sym_db.RegisterMessage(ListTransferLogsRequest)

ListTransferLogsResponse = _reflection.GeneratedProtocolMessageType(
    "ListTransferLogsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTTRANSFERLOGSRESPONSE,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """The returned list transfer run messages.
  
  Attributes:
      transfer_messages:
          Output only. The stored pipeline transfer messages.
      next_page_token:
          Output only. The next-pagination token. For multiple-page list
          results, this token can be used as the
          ``GetTransferRunLogRequest.page_token`` to request the next
          page of list results.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.ListTransferLogsResponse)
    },
)
_sym_db.RegisterMessage(ListTransferLogsResponse)

CheckValidCredsRequest = _reflection.GeneratedProtocolMessageType(
    "CheckValidCredsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CHECKVALIDCREDSREQUEST,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """A request to determine whether the user has valid credentials. This
  method is used to limit the number of OAuth popups in the user
  interface. The user id is inferred from the API call context. If the
  data source has the Google+ authorization type, this method returns
  false, as it cannot be determined whether the credentials are already
  valid merely based on the user id.
  
  Attributes:
      name:
          Required. The data source in the form:
          ``projects/{project_id}/dataSources/{data_source_id}`` or ``pr
          ojects/{project_id}/locations/{location_id}/dataSources/{data_
          source_id}``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.CheckValidCredsRequest)
    },
)
_sym_db.RegisterMessage(CheckValidCredsRequest)

CheckValidCredsResponse = _reflection.GeneratedProtocolMessageType(
    "CheckValidCredsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _CHECKVALIDCREDSRESPONSE,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """A response indicating whether the credentials exist and are valid.
  
  Attributes:
      has_valid_creds:
          If set to ``true``, the credentials exist and are valid.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.CheckValidCredsResponse)
    },
)
_sym_db.RegisterMessage(CheckValidCredsResponse)

ScheduleTransferRunsRequest = _reflection.GeneratedProtocolMessageType(
    "ScheduleTransferRunsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _SCHEDULETRANSFERRUNSREQUEST,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """A request to schedule transfer runs for a time range.
  
  Attributes:
      parent:
          Required. Transfer configuration name in the form:
          ``projects/{project_id}/transferConfigs/{config_id}`` or ``pro
          jects/{project_id}/locations/{location_id}/transferConfigs/{co
          nfig_id}``.
      start_time:
          Required. Start time of the range of transfer runs. For
          example, ``"2017-05-25T00:00:00+00:00"``.
      end_time:
          Required. End time of the range of transfer runs. For example,
          ``"2017-05-30T00:00:00+00:00"``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.ScheduleTransferRunsRequest)
    },
)
_sym_db.RegisterMessage(ScheduleTransferRunsRequest)

ScheduleTransferRunsResponse = _reflection.GeneratedProtocolMessageType(
    "ScheduleTransferRunsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _SCHEDULETRANSFERRUNSRESPONSE,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """A response to schedule transfer runs for a time range.
  
  Attributes:
      runs:
          The transfer runs that were scheduled.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.ScheduleTransferRunsResponse)
    },
)
_sym_db.RegisterMessage(ScheduleTransferRunsResponse)

StartManualTransferRunsRequest = _reflection.GeneratedProtocolMessageType(
    "StartManualTransferRunsRequest",
    (_message.Message,),
    {
        "TimeRange": _reflection.GeneratedProtocolMessageType(
            "TimeRange",
            (_message.Message,),
            {
                "DESCRIPTOR": _STARTMANUALTRANSFERRUNSREQUEST_TIMERANGE,
                "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
                "__doc__": """A specification for a time range, this will request transfer runs with
    run_time between start_time (inclusive) and end_time (exclusive).
    
    Attributes:
        start_time:
            Start time of the range of transfer runs. For example,
            ``"2017-05-25T00:00:00+00:00"``. The start_time must be
            strictly less than the end_time. Creates transfer runs where
            run_time is in the range betwen start_time (inclusive) and
            end_time (exlusive).
        end_time:
            End time of the range of transfer runs. For example,
            ``"2017-05-30T00:00:00+00:00"``. The end_time must not be in
            the future. Creates transfer runs where run_time is in the
            range betwen start_time (inclusive) and end_time (exlusive).
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.StartManualTransferRunsRequest.TimeRange)
            },
        ),
        "DESCRIPTOR": _STARTMANUALTRANSFERRUNSREQUEST,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """A request to start manual transfer runs.
  
  Attributes:
      parent:
          Transfer configuration name in the form:
          ``projects/{project_id}/transferConfigs/{config_id}`` or ``pro
          jects/{project_id}/locations/{location_id}/transferConfigs/{co
          nfig_id}``.
      time:
          The requested time specification - this can be a time range or
          a specific run_time.
      requested_time_range:
          Time range for the transfer runs that should be started.
      requested_run_time:
          Specific run_time for a transfer run to be started. The
          requested_run_time must not be in the future.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.StartManualTransferRunsRequest)
    },
)
_sym_db.RegisterMessage(StartManualTransferRunsRequest)
_sym_db.RegisterMessage(StartManualTransferRunsRequest.TimeRange)

StartManualTransferRunsResponse = _reflection.GeneratedProtocolMessageType(
    "StartManualTransferRunsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _STARTMANUALTRANSFERRUNSRESPONSE,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.datatransfer_pb2",
        "__doc__": """A response to start manual transfer runs.
  
  Attributes:
      runs:
          The transfer runs that were created.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.StartManualTransferRunsResponse)
    },
)
_sym_db.RegisterMessage(StartManualTransferRunsResponse)


DESCRIPTOR._options = None
_DATASOURCE.fields_by_name["name"]._options = None
_DATASOURCE.fields_by_name["transfer_type"]._options = None
_DATASOURCE.fields_by_name["supports_multiple_transfers"]._options = None
_DATASOURCE._options = None
_GETDATASOURCEREQUEST.fields_by_name["name"]._options = None
_LISTDATASOURCESREQUEST.fields_by_name["parent"]._options = None
_LISTDATASOURCESRESPONSE.fields_by_name["next_page_token"]._options = None
_CREATETRANSFERCONFIGREQUEST.fields_by_name["parent"]._options = None
_CREATETRANSFERCONFIGREQUEST.fields_by_name["transfer_config"]._options = None
_UPDATETRANSFERCONFIGREQUEST.fields_by_name["transfer_config"]._options = None
_UPDATETRANSFERCONFIGREQUEST.fields_by_name["update_mask"]._options = None
_GETTRANSFERCONFIGREQUEST.fields_by_name["name"]._options = None
_DELETETRANSFERCONFIGREQUEST.fields_by_name["name"]._options = None
_GETTRANSFERRUNREQUEST.fields_by_name["name"]._options = None
_DELETETRANSFERRUNREQUEST.fields_by_name["name"]._options = None
_LISTTRANSFERCONFIGSREQUEST.fields_by_name["parent"]._options = None
_LISTTRANSFERCONFIGSRESPONSE.fields_by_name["transfer_configs"]._options = None
_LISTTRANSFERCONFIGSRESPONSE.fields_by_name["next_page_token"]._options = None
_LISTTRANSFERRUNSREQUEST.fields_by_name["parent"]._options = None
_LISTTRANSFERRUNSRESPONSE.fields_by_name["transfer_runs"]._options = None
_LISTTRANSFERRUNSRESPONSE.fields_by_name["next_page_token"]._options = None
_LISTTRANSFERLOGSREQUEST.fields_by_name["parent"]._options = None
_LISTTRANSFERLOGSRESPONSE.fields_by_name["transfer_messages"]._options = None
_LISTTRANSFERLOGSRESPONSE.fields_by_name["next_page_token"]._options = None
_CHECKVALIDCREDSREQUEST.fields_by_name["name"]._options = None
_SCHEDULETRANSFERRUNSREQUEST.fields_by_name["parent"]._options = None
_SCHEDULETRANSFERRUNSREQUEST.fields_by_name["start_time"]._options = None
_SCHEDULETRANSFERRUNSREQUEST.fields_by_name["end_time"]._options = None
_STARTMANUALTRANSFERRUNSREQUEST.fields_by_name["parent"]._options = None

_DATATRANSFERSERVICE = _descriptor.ServiceDescriptor(
    name="DataTransferService",
    full_name="google.cloud.bigquery.datatransfer.v1.DataTransferService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A#bigquerydatatransfer.googleapis.com\322A.https://www.googleapis.com/auth/cloud-platform",
    create_key=_descriptor._internal_create_key,
    serialized_start=5683,
    serialized_end=9718,
    methods=[
        _descriptor.MethodDescriptor(
            name="GetDataSource",
            full_name="google.cloud.bigquery.datatransfer.v1.DataTransferService.GetDataSource",
            index=0,
            containing_service=None,
            input_type=_GETDATASOURCEREQUEST,
            output_type=_DATASOURCE,
            serialized_options=b"\202\323\344\223\002X\022//v1/{name=projects/*/locations/*/dataSources/*}Z%\022#/v1/{name=projects/*/dataSources/*}\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListDataSources",
            full_name="google.cloud.bigquery.datatransfer.v1.DataTransferService.ListDataSources",
            index=1,
            containing_service=None,
            input_type=_LISTDATASOURCESREQUEST,
            output_type=_LISTDATASOURCESRESPONSE,
            serialized_options=b"\202\323\344\223\002X\022//v1/{parent=projects/*/locations/*}/dataSourcesZ%\022#/v1/{parent=projects/*}/dataSources\332A\006parent",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="CreateTransferConfig",
            full_name="google.cloud.bigquery.datatransfer.v1.DataTransferService.CreateTransferConfig",
            index=2,
            containing_service=None,
            input_type=_CREATETRANSFERCONFIGREQUEST,
            output_type=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2._TRANSFERCONFIG,
            serialized_options=b'\202\323\344\223\002\202\001"3/v1/{parent=projects/*/locations/*}/transferConfigs:\017transfer_configZ:"\'/v1/{parent=projects/*}/transferConfigs:\017transfer_config\332A\026parent,transfer_config',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="UpdateTransferConfig",
            full_name="google.cloud.bigquery.datatransfer.v1.DataTransferService.UpdateTransferConfig",
            index=3,
            containing_service=None,
            input_type=_UPDATETRANSFERCONFIGREQUEST,
            output_type=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2._TRANSFERCONFIG,
            serialized_options=b"\202\323\344\223\002\242\0012C/v1/{transfer_config.name=projects/*/locations/*/transferConfigs/*}:\017transfer_configZJ27/v1/{transfer_config.name=projects/*/transferConfigs/*}:\017transfer_config\332A\033transfer_config,update_mask",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DeleteTransferConfig",
            full_name="google.cloud.bigquery.datatransfer.v1.DataTransferService.DeleteTransferConfig",
            index=4,
            containing_service=None,
            input_type=_DELETETRANSFERCONFIGREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002`*3/v1/{name=projects/*/locations/*/transferConfigs/*}Z)*'/v1/{name=projects/*/transferConfigs/*}\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="GetTransferConfig",
            full_name="google.cloud.bigquery.datatransfer.v1.DataTransferService.GetTransferConfig",
            index=5,
            containing_service=None,
            input_type=_GETTRANSFERCONFIGREQUEST,
            output_type=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2._TRANSFERCONFIG,
            serialized_options=b"\202\323\344\223\002`\0223/v1/{name=projects/*/locations/*/transferConfigs/*}Z)\022'/v1/{name=projects/*/transferConfigs/*}\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListTransferConfigs",
            full_name="google.cloud.bigquery.datatransfer.v1.DataTransferService.ListTransferConfigs",
            index=6,
            containing_service=None,
            input_type=_LISTTRANSFERCONFIGSREQUEST,
            output_type=_LISTTRANSFERCONFIGSRESPONSE,
            serialized_options=b"\202\323\344\223\002`\0223/v1/{parent=projects/*/locations/*}/transferConfigsZ)\022'/v1/{parent=projects/*}/transferConfigs\332A\006parent",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ScheduleTransferRuns",
            full_name="google.cloud.bigquery.datatransfer.v1.DataTransferService.ScheduleTransferRuns",
            index=7,
            containing_service=None,
            input_type=_SCHEDULETRANSFERRUNSREQUEST,
            output_type=_SCHEDULETRANSFERRUNSRESPONSE,
            serialized_options=b'\210\002\001\202\323\344\223\002\204\001"B/v1/{parent=projects/*/locations/*/transferConfigs/*}:scheduleRuns:\001*Z;"6/v1/{parent=projects/*/transferConfigs/*}:scheduleRuns:\001*\332A\032parent,start_time,end_time',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="StartManualTransferRuns",
            full_name="google.cloud.bigquery.datatransfer.v1.DataTransferService.StartManualTransferRuns",
            index=8,
            containing_service=None,
            input_type=_STARTMANUALTRANSFERRUNSREQUEST,
            output_type=_STARTMANUALTRANSFERRUNSRESPONSE,
            serialized_options=b'\202\323\344\223\002\212\001"E/v1/{parent=projects/*/locations/*/transferConfigs/*}:startManualRuns:\001*Z>"9/v1/{parent=projects/*/transferConfigs/*}:startManualRuns:\001*',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="GetTransferRun",
            full_name="google.cloud.bigquery.datatransfer.v1.DataTransferService.GetTransferRun",
            index=9,
            containing_service=None,
            input_type=_GETTRANSFERRUNREQUEST,
            output_type=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2._TRANSFERRUN,
            serialized_options=b"\202\323\344\223\002n\022:/v1/{name=projects/*/locations/*/transferConfigs/*/runs/*}Z0\022./v1/{name=projects/*/transferConfigs/*/runs/*}\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DeleteTransferRun",
            full_name="google.cloud.bigquery.datatransfer.v1.DataTransferService.DeleteTransferRun",
            index=10,
            containing_service=None,
            input_type=_DELETETRANSFERRUNREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002n*:/v1/{name=projects/*/locations/*/transferConfigs/*/runs/*}Z0*./v1/{name=projects/*/transferConfigs/*/runs/*}\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListTransferRuns",
            full_name="google.cloud.bigquery.datatransfer.v1.DataTransferService.ListTransferRuns",
            index=11,
            containing_service=None,
            input_type=_LISTTRANSFERRUNSREQUEST,
            output_type=_LISTTRANSFERRUNSRESPONSE,
            serialized_options=b"\202\323\344\223\002n\022:/v1/{parent=projects/*/locations/*/transferConfigs/*}/runsZ0\022./v1/{parent=projects/*/transferConfigs/*}/runs\332A\006parent",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListTransferLogs",
            full_name="google.cloud.bigquery.datatransfer.v1.DataTransferService.ListTransferLogs",
            index=12,
            containing_service=None,
            input_type=_LISTTRANSFERLOGSREQUEST,
            output_type=_LISTTRANSFERLOGSRESPONSE,
            serialized_options=b"\202\323\344\223\002\214\001\022I/v1/{parent=projects/*/locations/*/transferConfigs/*/runs/*}/transferLogsZ?\022=/v1/{parent=projects/*/transferConfigs/*/runs/*}/transferLogs\332A\006parent",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="CheckValidCreds",
            full_name="google.cloud.bigquery.datatransfer.v1.DataTransferService.CheckValidCreds",
            index=13,
            containing_service=None,
            input_type=_CHECKVALIDCREDSREQUEST,
            output_type=_CHECKVALIDCREDSRESPONSE,
            serialized_options=b'\202\323\344\223\002~"?/v1/{name=projects/*/locations/*/dataSources/*}:checkValidCreds:\001*Z8"3/v1/{name=projects/*/dataSources/*}:checkValidCreds:\001*\332A\004name',
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_DATATRANSFERSERVICE)

DESCRIPTOR.services_by_name["DataTransferService"] = _DATATRANSFERSERVICE

# @@protoc_insertion_point(module_scope)
